import requests
import pandas as pd

class DatasetClient:
    def __init__(self, api_url):
        self.api_url = api_url

    def get_dataset(self):
        """Fetch dataset from the API and return as a Pandas DataFrame."""
        response = requests.get(self.api_url)
        if response.status_code == 200:
            response_data = response.json()
            if "data" in response_data:
                return pd.DataFrame(response_data["data"])
            else:
                return response_data
        else:
            print(f"Error fetching dataset: {response.text}")
            return None

    def add_data(self, data, operation_type):
        """Insert new records into the dataset via API."""
        payload = {"data": data, "operation_type": operation_type}
        response = requests.post(self.api_url, json=payload)
        return response.json()

    def update_data(self, data):
        """Update existing records in the dataset."""
        payload = {"data": data}
        response = requests.put(self.api_url, json=payload)
        return response.json()

    def delete_data(self, delete_ids):
        """Delete records from the dataset using their IDs."""
        payload = {"delete_ids": delete_ids}
        response = requests.delete(self.api_url, json=payload)
        return response.json()

    @staticmethod
    def data_from_csv_data_frame(file_path):
        new_df = pd.read_csv(file_path)
        for col in new_df.select_dtypes(exclude=['object']).columns:
            new_df[col] = new_df[col].astype(str)
        new_df.fillna("", inplace=True)
        return new_df.to_dict(orient="records")
